/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file uart.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "uart.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/
/******************************************************************************
 ** \brief UART_ConfigRunMode
 **			UARTģʽ
 ** \param [in]     UARTMode:		(1)UART_MOD_SYN : ͬģʽ
 **									(2)UART_MOD_ASY_8BIT: 8λ첽ģʽ
 **									(3)UART_MOD_ASY_9BIT9λ첽ģʽ
 **									(4)UART_MOD_ASY_9BIT_STATIC9λʹ̶첽ģʽ
 **					UARTBaudTimer:  (1)UART_BAUD_TMR1 :	Timer1
 **									(2)UART_BAUD_TMR4 :	Timer4
 **									(3)UART_BAUD_TMR2 : Timer2
 **									(4)UART_BAUD_BRT : BRT
 ** \return none
******************************************************************************/
void UART_ConfigRunMode(uint8_t UARTMode, uint8_t UARTBaudTimer)
{	
	SCON0 &= ~(UART_SCON0_U0SMn_Msk);
	SCON0 |= (UARTMode<< UART_SCON0_U0SMn_Pos);
	FUNCCR &= ~(SYS_FUNCCR_UART0_CKS_Msk);
	FUNCCR |= UARTBaudTimer;		
}
/******************************************************************************
 ** \brief UART_EnableDoubleFrequency
 **			ʹUARTʱƵģʽ
 ** \param [in] none  
 ** \return none
******************************************************************************/
void UART_EnableDoubleFrequency(void)
{
	PCON |= SYS_PCON_SMOD0_Msk;
}
/******************************************************************************
 ** \brief UART_DisableDoubleFrequency
 **			رUARTʱƵģʽ
 ** \param [in]none
 ** \return none
******************************************************************************/
void UART_DisableDoubleFrequency(void)
{
	PCON &= ~(SYS_PCON_SMOD0_Msk);		
}

/******************************************************************************
 ** \brief UART_ConfigBaudRate
 **			UART
 ** \param [in]BaudRateValue:  ֵ
 ** \return Timer1/4: 8λԶװģʽTHxֵ
 **			Timer2: 16 λԶװģʽ RLDH:RLDL ֵ
 **			BRT: 16 λʱģʽ BRTH:BRTL ֵ
******************************************************************************/
uint16_t UART_ConfigBaudRate(uint32_t BaudRateValue)
{
#ifdef  USE_FORMULA
	float  BaudRateTemp =0;	
	float  BaudRate = 0.55;
	uint16_t PeriodValue =0;
	uint8_t  SMOD_Flag =0;
	uint8_t  T_Flag =0;	
	uint8_t  BaudRateTimer =0;
	
	SMOD_Flag = 1;	

	if(PCON & SYS_PCON_SMOD0_Msk)
	{
			SMOD_Flag = 2;						/*ȡSMODλ*/
	}	
	BaudRateTimer = FUNCCR & SYS_FUNCCR_UART0_CKS_Msk;			
			
	switch(BaudRateTimer)
	{
		case UART_BAUD_TMR1:	// Timer1
			T_Flag = ((CKCON & TMR_CKCON_T1M_Msk)? 1:3);		/*ȡT1Mλ*/
			BaudRateTemp = 256 - SystemClock *SMOD_Flag/ 32 / 4 /T_Flag/BaudRateValue;					
			break;
		case UART_BAUD_TMR4:	// Timer4
			T_Flag = ((T34MOD & TMR_T34MOD_T4M_Msk)? 1:3);		/*ȡT4Mλ*/
			BaudRateTemp = 256 - SystemClock *SMOD_Flag/ 32 / 4 /T_Flag/BaudRateValue;			
			break;
		case UART_BAUD_TMR2:	// Timer2
			T_Flag = (( T2CON & TMR_T2CON_T2PS_Msk)? 2:1);			/*ȡT2PSλ*/
			BaudRateTemp = 65536 - SystemClock *SMOD_Flag/ 32 / 12 /T_Flag/BaudRateValue; 		
			break;			
		case UART_BAUD_BRT:	// BRT
			T_Flag = BRTCON & UART_BRTCON_BRTCKDIV_Msk;		/*ȡBRTCLKVIVλ*/
			BaudRateTemp = 65536 - SystemClock *SMOD_Flag/ 32 / (1<< T_Flag)/BaudRateValue;	
			break;				
		default:
			break;
	}				
	if((BaudRateTemp - (uint16_t) BaudRateTemp) > BaudRate)
	{
		PeriodValue = (uint16_t)BaudRateTemp + 1;
	}
	else
	{
		PeriodValue = BaudRateTemp;
	}	
	return (PeriodValue);
#else	
	BaudRateValue =0;
	return 0;
#endif 
}

/******************************************************************************
 ** \brief UART_EnableReceive
 **			ģʽ
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_EnableReceive(void)
{
	U0REN =1;
}
/******************************************************************************
 ** \brief UART_DisableReceive
 **			رսģʽ
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_DisableReceive(void)
{
	U0REN =0;
}

/******************************************************************************
 ** \brief UART_EnableInt
 **			ж
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_EnableInt(void)
{
	ES0 =1;
}
/******************************************************************************
 ** \brief UART_DisableInt
 **			رж
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_DisableInt(void)
{
	ES0 =0;
}
/******************************************************************************
 ** \brief UART_GetReceiveIntFlag
 **			ȡжϱ־λ
 ** \param [in]none
 ** \return 0жϣ1ж
******************************************************************************/
uint8_t  UART_GetReceiveIntFlag(void)
{
	return ((SCON0 & UART_SCON0_RI0_Msk)? 1:0) ;
}

/******************************************************************************
 ** \brief UART_ClearReceiveIntFlag
 **			жϱ־λ
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_ClearReceiveIntFlag(void)
{
	RI0=0;
}

/******************************************************************************
 ** \brief UART_GetSendIntFlag
 **			ȡжϱ־λ
 ** \param [in]none
 ** \return 0жϣ1ж
******************************************************************************/
uint8_t  UART_GetSendIntFlag(void)
{		
	return ((SCON0 & UART_SCON0_TI0_Msk)? 1:0);
}

/******************************************************************************
 ** \brief UART_ClearSendIntFlag
 **			жϱ־λ
 ** \param [in]none
 ** \return 
******************************************************************************/
void UART_ClearSendIntFlag(void)
{
	TI0=0;
}

/******************************************************************************
 ** \brief UART_GetBuff
 **			ȡBuffֵ
 ** \param [in]none
 ** \return 
******************************************************************************/
uint8_t UART_GetBuff(void)
{	
	return SBUF0;
}

/******************************************************************************
 ** \brief UART_SendBuff
 **			ݵBuff
 ** \param [in] UARTSendValue : ͵8λֵ
 ** \return 
******************************************************************************/
void UART_SendBuff( uint8_t UARTSendValue)
{
	SBUF0 = UARTSendValue;		
}

/******************************************************************************
 ** \brief UART_SendNinthBit
 **			ݵĵھλ
 ** \param [in]UARTSendValue : ͵ĵھλֵ
 ** \return 
******************************************************************************/
void UART_SendNinthBit( uint8_t UARTSendValue)
{
	if(0 == UARTSendValue)
	{
		U0TB8 =0;
	}
	else
	{
		U0TB8 =1;
	}	
}
/******************************************************************************
 ** \brief UART_GetNinthBit
 **			ȡݵĵھλ
 ** \param [in]none
 ** \return 0/1
******************************************************************************/
uint8_t UART_GetNinthBit(void)
{
	return ((SCON0 & UART_SCON0_U0RB8_Msk)? 1:0);
}

/******************************************************************************
 ** \brief UART_EnableBRT
 **		   ʹBRTʱģ
 ** \param [in]none
 ** \return none
******************************************************************************/
void UART_EnableBRT(void)
{
	BRTCON |= UART_BRTCON_BRTEN_Msk;	
}
/******************************************************************************
 ** \brief UART_ConfigBRTClk
 **		   BRTģʱ
 ** \param [in]BRTClkDiv : BRT_CLK_DIV_1 ~ BRT_CLK_DIV_128
 ** \return none
******************************************************************************/
void UART_ConfigBRTClk( uint8_t BRTClkDiv)
{
	BRTCON &= ~(UART_BRTCON_BRTCKDIV_Msk);	
	BRTCON |= BRTClkDiv;			
}

/******************************************************************************
 ** \brief UART_ConfigBRTPeriod
 **		   BRTģʱ
 ** \param [in] BRTPeriod: 16bit
 ** \return none
******************************************************************************/
void UART_ConfigBRTPeriod( uint16_t BRTPeriod)
{	
	BRTDL = BRTPeriod;
	BRTDH = BRTPeriod>>8;	
}
/******************************************************************************
 ** \brief UART_DisableBRT
 **		   رBRTʱģ
 ** \param [in]none
 ** \return none
******************************************************************************/
void UART_DisableBRT(void)
{
	BRTCON &= ~(UART_BRTCON_BRTEN_Msk);
}







